#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-EzITZzhgqVHEP9Zf8ubzhT
key:                  dhall-1.42.3-EzITZzhgqVHEP9Zf8ubzhT
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  1e8d902d31cd29c1ac172482b3e8f4ed
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-EzITZzhgqVHEP9Zf8ubzhT
depends:
    Diff-0.5-DaaQBhVKLTM3OHP5tNzqLY
    aeson-2.2.1.0-LCgCxr5fZ2fF779OJkJoWg
    aeson-pretty-0.8.10-BCZjZcWfOQs89IrHvEUetC
    ansi-terminal-1.1-CI6FO6RG7vk9kCajbldbD2
    atomic-write-0.2.1.1-AfurOZvqWaqBPbhQq3UXD0 base-4.18.2.1
    base16-bytestring-1.0.2.0-G41qG77WeTiJP0VEPyRPnI
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8jGUMPhZyRG9nNczCrjpjo
    cborg-0.2.10.0-HgzK4Jp4JKl93Ycn4ZCZSG
    cborg-json-0.2.6.0-11tCPvH9kDvFbvAZsXf7cM containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-GTHJTXzqOBm1L67cXOiZnP
    data-fix-0.3.4-3aU8YdUU37f1B7IxiKqyYq deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-6JNpvqdNlNX5UyGARS1Jtp exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-7CrYsMBKxmXIWmPAMXvngm
    hashable-1.4.7.0-8DiXdwI1HyoGIpw8Heqw3G haskeline-0.8.2.1
    http-client-0.7.19-7Wwvx82yqlRGIUYbPQupWM
    http-client-tls-0.3.6.4-JiThctbTuGjJnqPKqN9uA0
    http-types-0.12.4-KZ6vNca015f4t5S0BZrDwk
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-4wuLWwPVTPr7ORUkj2k5pG
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-6zqYHFTN4FAKhZiyZc7uW4
    optparse-applicative-0.18.1.0-5rdJae4Jo9sKWG5YERkeVE
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-3KnNUfOPcAA6i2vI6jfWag
    pretty-simple-4.1.4.0-BSjQLZoZWSqCWc5NWi7IrA
    prettyprinter-1.7.1-eZs6LtbK8M8wXnTmHvu32
    prettyprinter-ansi-terminal-1.1.3-8KMwVKd8YM3Hu4h7aLdV2z
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-80BdERaFikj2hMbwn34B0N
    serialise-0.2.6.1-8tdjIFs3YMi1Aybw7qi0B1 template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-ARKEzQEGfac5WvKSs7jU4m
    text-short-0.1.6-Ag4w4TGum6a8JOHU4G7JoK
    th-lift-instances-0.1.20-FYyn5gZAUg6CQBQP1MAkwq time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-KbYhInnVrhVCVJECNv1JBA
    unordered-containers-0.2.20.1-LFprVvrjTX4JVFniJRp7e6
    vector-0.13.2.0-KR0oqssWe4cgn21CCdckk

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

